From 055760baae36559cdf7fb94b7ac0ae78331552a1 Mon Sep 17 00:00:00 2001
From: Moul <moul@moul.re>
Date: Sun, 30 Oct 2022 11:39:50 +0100
Subject: [PATCH] Update end_to_end tests

balance: fix string to use balance and not amount
---
 silkaj/money/balance.py              |  2 +-
 tests/integration/test_end_to_end.py | 18 +++++++++---------
 2 files changed, 10 insertions(+), 10 deletions(-)

diff --git a/silkaj/money/balance.py b/silkaj/money/balance.py
index 61c02fce..3079f887 100644
--- a/silkaj/money/balance.py
+++ b/silkaj/money/balance.py
@@ -103,7 +103,7 @@ def show_amount_from_pubkey(label: str, inputs_balance: List[int]) -> None:
             currency_symbol,
         )
     m_tools.display_amount(
-        display, "Total amount", totalAmountInput, ud_value, currency_symbol
+        display, "Total balance", totalAmountInput, ud_value, currency_symbol
     )
     display.append(
         [
diff --git a/tests/integration/test_end_to_end.py b/tests/integration/test_end_to_end.py
index 5355548a..2eceb638 100644
--- a/tests/integration/test_end_to_end.py
+++ b/tests/integration/test_end_to_end.py
@@ -19,13 +19,13 @@ silkaj = ["poetry", "run", "silkaj"]
 
 
 def test_info():
-    """tests 'silkaj info' returns a number of members"""
+    """tests 'silkaj blockchain info' returns a number of members"""
 
     output = check_output(silkaj + ["blockchain", "info"])
     assert "Number of members" in output.decode()
 
 
-def test_wot():
+def test_wot_status():
     """tests 'silkaj wot status' returns a number of members"""
 
     output = check_output(silkaj + ["wot", "status", "Matograine"]).decode()
@@ -36,15 +36,15 @@ def test_wot():
     assert "sent_expire" in output
 
 
-def test_id():
-    """tests 'silkaj lookup' certification on gtest"""
+def test_wot_lookup():
+    """tests 'silkaj wot lookup' certification on gtest"""
 
     output = check_output(silkaj + ["--gtest", "wot", "lookup", "elois"]).decode()
     assert "D7CYHJXjaH4j7zRdWngUbsURPnSnjsCYtvo6f8dvW3C" in output
 
 
-def test_balance():
-    """tests 'silkaj amount' command on gtest"""
+def test_money_balance():
+    """tests 'silkaj money balance' command on gtest"""
 
     output = check_output(
         silkaj
@@ -56,10 +56,10 @@ def test_balance():
         ]
     ).decode()
     assert (
-        "│ Balance of pubkey            │ 3dnbnYY9i2bHMQUGyFp5GVvJ2wBkVpus31cDJA5cfRpj: │"
+        "│ Balance of pubkey             │ 3dnbnYY9i2bHMQUGyFp5GVvJ2wBkVpus31cDJA5cfRpj │"
         in output
     )
-    assert "EyF" in output
-    assert "│ Total amount (unit|relative) │" in output
+    assert ":EyF" in output
+    assert "│ Total balance (unit|relative) │" in output
     assert "UD ÄžTest" in output
     assert "Total relative to M/N" in output
-- 
GitLab